@@ -26,6 +26,7 @@ import java.io.InputStream;
 import java.math.BigInteger;
 import java.text.ParseException;
 import java.util.Arrays;
+import java.util.Comparator;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
@@ -43,27 +44,31 @@ import org.vafer.jdeb.utils.InformationInputStream;
 import org.vafer.jdeb.utils.Utils;
 import org.vafer.jdeb.utils.VariableResolver;
 
+import static java.nio.charset.StandardCharsets.*;
+
 /**
  * Builds the control archive of the Debian package.
  */
 class ControlBuilder {
 
     /** The name of the package maintainer scripts */
-    private static final Set<String> MAINTAINER_SCRIPTS = new HashSet<String>(Arrays.asList("preinst", "postinst", "prerm", "postrm", "config"));
+    private static final Set<String> MAINTAINER_SCRIPTS = new HashSet<>(Arrays.asList("preinst", "postinst", "prerm", "postrm", "config"));
 
     /** The name of the other control files subject to token substitution */
-    private static final Set<String> CONFIGURATION_FILENAMES = new HashSet<String>(Arrays.asList("conffiles", "templates", "triggers", "copyright"));
+    private static final Set<String> CONFIGURATION_FILENAMES = new HashSet<>(Arrays.asList("conffiles", "templates", "triggers", "copyright"));
 
     private Console console;
     private VariableResolver resolver;
     private final String openReplaceToken;
     private final String closeReplaceToken;
+    private final Long outputTimestampMs;
 
-    ControlBuilder(Console console, VariableResolver resolver, String openReplaceToken, String closeReplaceToken) {
+    ControlBuilder(Console console, VariableResolver resolver, String openReplaceToken, String closeReplaceToken, Long outputTimestampMs) {
         this.console = console;
         this.resolver = resolver;
         this.openReplaceToken = openReplaceToken;
         this.closeReplaceToken = closeReplaceToken;
+        this.outputTimestampMs = outputTimestampMs;
     }
 
     /**
@@ -71,7 +76,7 @@ class ControlBuilder {
      *
      * @param packageControlFile the package control file
      * @param controlFiles the other control information files (maintainer scripts, etc)
-     * @param dataSize  the size of the installed package
+     * @param conffiles    the configuration files
      * @param checksums the md5 checksums of the files in the data archive
      * @param output
      * @return
@@ -90,7 +95,10 @@ class ControlBuilder {
 
         boolean foundConffiles = false;
 
-        // create the final package control file out of the "control" file, copy all other files, ignore the directories
+        // sort files to have consistent/reproducible builds
+		Arrays.sort(controlFiles, Comparator.comparing(File::toString));
+
+		// create the final package control file out of the "control" file, copy all other files, ignore the directories
         for (File file : controlFiles) {
             if (file.isDirectory()) {
                 // warn about the misplaced directory, except for directories ignored by default (.svn, cvs, etc)
@@ -206,12 +214,15 @@ class ControlBuilder {
     }
 
 
-    private static void addControlEntry(final String pName, final String pContent, final TarArchiveOutputStream pOutput) throws IOException {
-        final byte[] data = pContent.getBytes("UTF-8");
+    private void addControlEntry(final String pName, final String pContent, final TarArchiveOutputStream pOutput) throws IOException {
+        final byte[] data = pContent.getBytes(UTF_8);
 
         final TarArchiveEntry entry = new TarArchiveEntry("./" + pName, true);
         entry.setSize(data.length);
         entry.setNames("root", "root");
+        if (outputTimestampMs != null) {
+            entry.setModTime(outputTimestampMs);
+        }
 
         if (MAINTAINER_SCRIPTS.contains(pName)) {
             entry.setMode(PermMapper.toMode("755"));
