@@ -22,6 +22,7 @@ import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.io.IOUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.bouncycastle.bcpg.HashAlgorithmTags;
 import org.bouncycastle.crypto.digests.MD5Digest;
 import org.bouncycastle.jce.provider.BouncyCastleProvider;
@@ -46,6 +47,7 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.math.BigInteger;
+import java.nio.charset.StandardCharsets;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 import java.security.Security;
@@ -55,6 +57,7 @@ import java.util.Collection;
 import java.util.Date;
 import java.util.List;
 import java.util.Locale;
+import java.util.concurrent.TimeUnit;
 
 /**
  * A generic class for creating Debian archives. Even supports signed changes
@@ -62,6 +65,8 @@ import java.util.Locale;
  */
 public class DebMaker {
 
+    private static final int DEFAULT_MODE = 33188;
+
     /** A console to output log message with */
     private Console console;
 
@@ -125,14 +130,16 @@ public class DebMaker {
     /** Defines the bigNumberMode of the tar file that is built */
     private String tarBigNumberMode;
 
+    private Long outputTimestampMs;
+
     private VariableResolver variableResolver;
     private String openReplaceToken;
     private String closeReplaceToken;
 
-    private final Collection<DataProducer> dataProducers = new ArrayList<DataProducer>();
+    private final Collection<DataProducer> dataProducers = new ArrayList<>();
 
-    private final Collection<DataProducer> conffilesProducers = new ArrayList<DataProducer>();
-    private String digest = "SHA1";
+    private final Collection<DataProducer> conffilesProducers = new ArrayList<>();
+    private String digest = "SHA256";
 
     public DebMaker(Console console, Collection<DataProducer> dataProducers, Collection<DataProducer> conffileProducers) {
         this.console = console;
@@ -242,6 +249,10 @@ public class DebMaker {
         this.tarBigNumberMode = tarBigNumberMode;
     }
 
+    public void setOutputTimestampMs(Long outputTimestampMs) {
+        this.outputTimestampMs = outputTimestampMs;
+    }
+
     /**
      * Validates the input parameters.
      */
@@ -309,31 +320,23 @@ public class DebMaker {
             console.info("Creating debian package: " + deb);
 
             // If we should sign the package
-            boolean doSign = signPackage;
-
-            if (doSign) {
+            if (signPackage) {
 
                 if (keyring == null || !keyring.exists()) {
-                    doSign = false;
                     console.warn("Signing requested, but no keyring supplied");
                 }
 
                 if (key == null) {
-                    doSign = false;
                     console.warn("Signing requested, but no key supplied");
                 }
 
                 if (passphrase == null) {
-                    doSign = false;
                     console.warn("Signing requested, but no passphrase supplied");
                 }
 
-                FileInputStream keyRingInput = new FileInputStream(keyring);
-                PGPSigner signer = null;
-                try {
-                    signer = new PGPSigner(new FileInputStream(keyring), key, passphrase, getDigestCode(digest));
-                } finally {
-                    keyRingInput.close();
+                PGPSigner signer;
+                try (FileInputStream keyRingInput = new FileInputStream(keyring)) {
+                    signer = new PGPSigner(keyRingInput, key, passphrase, getDigestCode(digest));
                 }
 
                 PGPSignatureGenerator signatureGenerator = new PGPSignatureGenerator(new BcPGPContentSignerBuilder(signer.getSecretKey().getPublicKey().getAlgorithm(), getDigestCode(digest)));
@@ -393,7 +396,7 @@ public class DebMaker {
                 PGPSigner signer = new PGPSigner(new FileInputStream(keyring), key, passphrase, getDigestCode(digest));
                 signer.clearSign(changesFile.toString(), out);
             } else {
-                out.write(changesFile.toString().getBytes("UTF-8"));
+                out.write(changesFile.toString().getBytes(StandardCharsets.UTF_8));
             }
             out.flush();
 
@@ -418,7 +421,7 @@ public class DebMaker {
     }
 
     private List<String> populateConffiles(Collection<DataProducer> producers) {
-        final List<String> result = new ArrayList<String>();
+        final List<String> result = new ArrayList<>();
 
         if (producers == null || producers.isEmpty()) {
             return result;
@@ -427,9 +430,15 @@ public class DebMaker {
         final DataConsumer receiver = new DataConsumer() {
             public void onEachFile(InputStream input, TarArchiveEntry entry)  {
                 String tempConffileItem = entry.getName();
+
+                // Make sure the conffile path is absolute
                 if (tempConffileItem.startsWith(".")) {
                     tempConffileItem = tempConffileItem.substring(1);
                 }
+                if (!tempConffileItem.startsWith("/")) {
+                    tempConffileItem = "/" + tempConffileItem;
+                }
+
                 console.info("Adding conffile: " + tempConffileItem);
                 result.add(tempConffileItem);
             }
@@ -480,7 +489,7 @@ public class DebMaker {
             tempControl = File.createTempFile("deb", "control");
 
             console.debug("Building data");
-            DataBuilder dataBuilder = new DataBuilder(console);
+            DataBuilder dataBuilder = new DataBuilder(console, outputTimestampMs);
             StringBuilder md5s = new StringBuilder();
             TarOptions options = new TarOptions()
                 .compression(compression)
@@ -492,7 +501,7 @@ public class DebMaker {
             List<String> tempConffiles = populateConffiles(conffilesProducers);
 
             console.debug("Building control");
-            ControlBuilder controlBuilder = new ControlBuilder(console, variableResolver, openReplaceToken, closeReplaceToken);
+            ControlBuilder controlBuilder = new ControlBuilder(console, variableResolver, openReplaceToken, closeReplaceToken, outputTimestampMs);
             BinaryPackageControlFile packageControlFile = controlBuilder.createPackageControlFile(new File(control, "control"), size);
             if (packageControlFile.get("Package") == null) {
                 packageControlFile.set("Package", packageName);
@@ -542,7 +551,7 @@ public class DebMaker {
                 }
 
                 // Use debsig-verify as default
-                if(signMethod == null || !"dpkg-sig".equals(signMethod)) {
+                if (!"dpkg-sig".equals(signMethod)) {
                     // Sign file to verify with debsig-verify
                     PGPSignatureOutputStream sigStream = new PGPSignatureOutputStream(signatureGenerator);
 
@@ -618,7 +627,7 @@ public class DebMaker {
         return null;
     }
 
-    private String md5Hash(byte input[]){
+    private String md5Hash(byte[] input){
         //update the input of MD5
         MD5Digest md5 = new MD5Digest();
         md5.update(input, 0, input.length);
@@ -645,7 +654,7 @@ public class DebMaker {
         return null;
     }
 
-    private String sha1Hash(byte input[]){
+    private String sha1Hash(byte[] input){
         try
         {
             //prepare the input
@@ -668,19 +677,19 @@ public class DebMaker {
 
     private void addTo(ArArchiveOutputStream pOutput, String pName, String pContent) throws IOException {
         final byte[] content = pContent.getBytes();
-        pOutput.putArchiveEntry(new ArArchiveEntry(pName, content.length));
+        ArArchiveEntry archiveEntry = createArArchiveEntry(pName, content.length);
+
+        pOutput.putArchiveEntry(archiveEntry);
         pOutput.write(content);
         pOutput.closeArchiveEntry();
     }
 
     private void addTo(ArArchiveOutputStream pOutput, String pName, File pContent) throws IOException {
-        pOutput.putArchiveEntry(new ArArchiveEntry(pName, pContent.length()));
+        ArArchiveEntry archiveEntry = createArArchiveEntry(pName, pContent.length());
 
-        final InputStream input = new FileInputStream(pContent);
-        try {
+        pOutput.putArchiveEntry(archiveEntry);
+		try (InputStream input = new FileInputStream(pContent)) {
             Utils.copy(input, pOutput);
-        } finally {
-            input.close();
         }
 
         pOutput.closeArchiveEntry();
@@ -692,11 +701,8 @@ public class DebMaker {
     }
 
     private void addTo(final PGPSignatureOutputStream pOutput, final File pContent) throws IOException {
-        final InputStream input = new FileInputStream(pContent);
-        try {
+        try (InputStream input = new FileInputStream(pContent)) {
             Utils.copy(input, pOutput);
-        } finally {
-            input.close();
         }
     }
 
@@ -707,4 +713,12 @@ public class DebMaker {
     public void setCloseReplaceToken(String closeReplaceToken) {
         this.closeReplaceToken = closeReplaceToken;
     }
+
+    private ArArchiveEntry createArArchiveEntry(String pName, long contentLength) {
+        if (outputTimestampMs != null) {
+            return new ArArchiveEntry(pName, contentLength, 0, 0, DEFAULT_MODE, outputTimestampMs / TimeUnit.SECONDS.toMillis(1));
+        }
+
+        return new ArArchiveEntry(pName, contentLength);
+    }
 }
