@@ -31,6 +31,7 @@ import org.vafer.jdeb.DataProducer;
 import org.vafer.jdeb.DebMaker;
 import org.vafer.jdeb.PackagingException;
 import org.vafer.jdeb.producers.DataProducerFileSet;
+import org.vafer.jdeb.utils.OutputTimestampResolver;
 
 /**
  * AntTask for creating debian archives.
@@ -69,15 +70,15 @@ public class DebAntTask extends MatchingTask {
      *
      * @see org.bouncycastle.bcpg.HashAlgorithmTags
      */
-    private String digest = "SHA1";
+    private String digest = "SHA256";
 
     /** Trigger the verbose mode detailing all operations */
     private boolean verbose;
 
-    private Collection<Link> links = new ArrayList<Link>();
+    private Collection<Link> links = new ArrayList<>();
 
-    private Collection<DataProducer> dataProducers = new ArrayList<DataProducer>();
-    private Collection<DataProducer> conffilesProducers = new ArrayList<DataProducer>();
+    private Collection<DataProducer> dataProducers = new ArrayList<>();
+    private Collection<DataProducer> conffilesProducers = new ArrayList<>();
 
 
     public void setDestfile( File deb ) {
@@ -174,6 +175,8 @@ public class DebAntTask extends MatchingTask {
         debMaker.setPassphrase(passphrase);
         debMaker.setCompression(compression);
         debMaker.setDigest(digest);
+        Long outputTimestampMs = new OutputTimestampResolver(console).resolveOutputTimestamp(null);
+        debMaker.setOutputTimestampMs(outputTimestampMs);
 
         try {
             debMaker.validate();
