@@ -51,6 +51,7 @@ import org.vafer.jdeb.DataProducer;
 import org.vafer.jdeb.DebMaker;
 import org.vafer.jdeb.PackagingException;
 import org.vafer.jdeb.utils.MapVariableResolver;
+import org.vafer.jdeb.utils.OutputTimestampResolver;
 import org.vafer.jdeb.utils.SymlinkUtils;
 import org.vafer.jdeb.utils.Utils;
 import org.vafer.jdeb.utils.VariableResolver;
@@ -171,7 +172,7 @@ public class DebMojo extends AbstractMojo {
      *
      * @see org.bouncycastle.bcpg.HashAlgorithmTags
      */
-    @Parameter(defaultValue = "SHA1")
+    @Parameter(defaultValue = "SHA256")
     private String digest;
 
     /**
@@ -359,6 +360,16 @@ public class DebMojo extends AbstractMojo {
     @Parameter(defaultValue = "gnu")
     private String tarBigNumberMode;
 
+    /**
+     * Timestamp for reproducible output archive entries, either formatted as ISO 8601
+     * <code>yyyy-MM-dd'T'HH:mm:ssXXX</code> or as an int representing seconds since the epoch (like
+     * <a href="https://reproducible-builds.org/docs/source-date-epoch/">SOURCE_DATE_EPOCH</a>).
+     *
+     * @since 1.9
+     */
+    @Parameter(defaultValue = "${project.build.outputTimestamp}")
+    private String outputTimestamp;
+
     /* end of parameters */
 
     private static final String KEY = "key";
@@ -368,8 +379,8 @@ public class DebMojo extends AbstractMojo {
     private String openReplaceToken = "[[";
     private String closeReplaceToken = "]]";
     private Console console;
-    private Collection<DataProducer> dataProducers = new ArrayList<DataProducer>();
-    private Collection<DataProducer> conffileProducers = new ArrayList<DataProducer>();
+    private Collection<DataProducer> dataProducers = new ArrayList<>();
+    private Collection<DataProducer> conffileProducers = new ArrayList<>();
 
     public void setOpenReplaceToken( String openReplaceToken ) {
         this.openReplaceToken = openReplaceToken;
@@ -394,14 +405,10 @@ public class DebMojo extends AbstractMojo {
         }
     }
 
+    @SuppressWarnings("unchecked,rawtypes")
     protected VariableResolver initializeVariableResolver( Map<String, String> variables ) {
-        @SuppressWarnings("unchecked")
-        final Map<String, String> projectProperties = Map.class.cast(getProject().getProperties());
-        @SuppressWarnings("unchecked")
-        final Map<String, String> systemProperties = Map.class.cast(System.getProperties());
-
-        variables.putAll(projectProperties);
-        variables.putAll(systemProperties);
+        variables.putAll((Map) getProject().getProperties());
+        variables.putAll((Map) System.getProperties());
         variables.put("name", name != null ? name : getProject().getName());
         variables.put("artifactId", getProject().getArtifactId());
         variables.put("groupId", getProject().getGroupId());
@@ -519,23 +526,19 @@ public class DebMojo extends AbstractMojo {
         if (dataProducers.isEmpty()) {
 
             if (hasMainArtifact()) {
-                Set<Artifact> artifacts = new HashSet<Artifact>();
+                Set<Artifact> artifacts = new HashSet<>();
 
                 artifacts.add(project.getArtifact());
 
                 @SuppressWarnings("unchecked")
                 final Set<Artifact> projectArtifacts = project.getArtifacts();
 
-                for (Artifact artifact : projectArtifacts) {
-                    artifacts.add(artifact);
-                }
+                artifacts.addAll(projectArtifacts);
 
                 @SuppressWarnings("unchecked")
                 final List<Artifact> attachedArtifacts = project.getAttachedArtifacts();
 
-                for (Artifact artifact : attachedArtifacts) {
-                    artifacts.add(artifact);
-                }
+                artifacts.addAll(attachedArtifacts);
 
                 for (Artifact artifact : artifacts) {
                     final File file = artifact.getFile();
@@ -599,6 +602,8 @@ public class DebMojo extends AbstractMojo {
             debMaker.setDigest(digest);
             debMaker.setTarBigNumberMode(tarBigNumberMode);
             debMaker.setTarLongFileMode(tarLongFileMode);
+            Long outputTimestampMs = new OutputTimestampResolver(console).resolveOutputTimestamp(outputTimestamp);
+            debMaker.setOutputTimestampMs(outputTimestampMs);
             debMaker.validate();
             debMaker.makeDeb();
 
@@ -727,8 +732,8 @@ public class DebMojo extends AbstractMojo {
             return Collections.emptyMap();
         }
 
-        final Map<String, String> map = new HashMap<String, String>();
-        final Set<String> activeProfiles = new HashSet<String>(activeProfilesList);
+        final Map<String, String> map = new HashMap<>();
+        final Set<String> activeProfiles = new HashSet<>(activeProfilesList);
 
         // Iterate over all active profiles in order
         for (final Profile profile : settings.getProfiles()) {
