@@ -23,5 +23,5 @@ package org.vafer.jdeb.utils;
  */
 
 public interface VariableResolver {
-    public String get( final String pKey );
+    String get( final String pKey );
 }
