@@ -69,12 +69,12 @@ public final class DataProducerPathTemplateTestCase extends Assert {
         assertEquals(invocation.user, "root");
     }
 
-    public class CaptureDataConsumer implements DataConsumer {
+    public static class CaptureDataConsumer implements DataConsumer {
 
         private List<Invocation> invocations;
 
         public CaptureDataConsumer() {
-            invocations = new ArrayList<Invocation>();
+            invocations = new ArrayList<>();
         }
 
         public void onEachDir(TarArchiveEntry dirEntry) throws IOException {
